@@ -345,7 +345,7 @@ use Carp;
 require Exporter;
 use AutoLoader;
 
-our $VERSION = '2.02';
+our $VERSION = '2.03';
 our @ISA = qw(Exporter);
 
 our @EXPORT = qw(
@@ -502,8 +502,6 @@ our @EXPORT = qw(
 	ZI_VECTOR_ELEMENT_TYPE_UINT32
 	ZI_VECTOR_ELEMENT_TYPE_UINT64
 	ZI_VECTOR_ELEMENT_TYPE_UINT8
-	ZI_VECTOR_WRITE_STATUS_IDLE
-	ZI_VECTOR_WRITE_STATUS_PENDING
 	ZI_WARNING
 	ZI_WARNING_BASE
 	ZI_WARNING_GENERAL
